#[repr(u8)]pub enum ErrorStateEnum {
Noerror = 0,
Unabletostartorresume = 1,
Unabletocompleteoperation = 2,
Commandinvalidinstate = 3,
}Variants
Noerror = 0
The device is not in an error state
Unabletostartorresume = 1
The device is unable to start or resume operation
Unabletocompleteoperation = 2
The device was unable to complete the current operation
Commandinvalidinstate = 3
The device cannot process the command in its current state
Implementations